@@ -7,12 +7,14 @@
 #define SONNET_SETTINGS_H
 
 #include <QAbstractListModel>
+#include <QObject>
 #include <QString>
 #include <QStringList>
-#include <QtCore/QObject>
 
 #include "sonnetcore_export.h"
 
+#include <memory>
+
 namespace Sonnet
 {
 class Loader;
@@ -115,9 +117,8 @@ Q_SIGNALS:
 
 private:
     friend class Loader;
-    SettingsPrivate *const d;
+    std::unique_ptr<SettingsPrivate> const d;
 };
 }
-Q_DECLARE_METATYPE(QAbstractListModel *)
 
 #endif // SONNET_SETTINGS_H
